@@ -3,8 +3,9 @@
 #' The standard errors, t statistics and p values have to be adjusted because of replicated rows.
 #' @param x lm object
 #' @param df_old integer number of d.f in original dataset
-#' @param df_new integer number of d.f in dataset with replicated rows
+#' @param df_new integer number of d.f in dataset with replicated rows, Default: x$df.residual
 #' @return data.frame with additional columns over a regular summary.lm output like correct and statistics adjusted by it.
+#' @importFrom stats pt
 #' @details The size of the correction is equal to sqrt(df_new / df_old).
 #' Where standard errors are multiplied and t statistics divided by it.
 #' @importFrom stats pnorm predict
@@ -32,13 +33,15 @@
 #' )
 #' summary_c2c(lms, df_old = nrow(occup_old), df_new = nrow(occup_2$old))
 #' @export
-summary_c2c <- function(x, df_old, df_new) {
-  ss <- summary(x)$coefficients
+summary_c2c <- function(x, df_old, df_new = x$df.residual) {
+  assert_that(inherits(x, "lm"))
+  ss <- summary(x)
+  cc <- ss$coefficients
   correct <- sqrt(df_new / df_old)
-  dd <- as.data.frame(ss)
+  dd <- as.data.frame(cc)
   dd$correct <- correct
   dd$std.error_c <- dd$`Std. Error` * correct
   dd$statistic_c <- dd$`t value` / correct
-  dd$p.value_c <- 2 * (1 - pnorm(abs(dd$statistic_c)))
+  dd$p.value_c <- 2 * pt(abs(dd$statistic_c), df_old, lower.tail = FALSE)
   dd
 }
